%global vertag a34989252e6f

Name:           snakeyaml
Summary:        YAML parser and emitter for Java
Version:        2.2
Release:        %mkrel 1
Group:          Development/Java
License:        ASL 2.0

URL:            https://bitbucket.org/%{name}/%{name}
Source0:        %{url}/get/%{name}-%{version}.tar.gz

# Upstream has forked gdata-java and base64 and refuses [1] to
# consider replacing them by external dependencies.  Bundled libraries
# need to be removed and their use replaced by system libraries.
# See rhbz#875777 and http://code.google.com/p/snakeyaml/issues/detail?id=175
#
# Replace use of bundled Base64 implementation with java.util.Base64
Patch0:         0001-replace-bundled-base64coder-with-java.util.Base64.patch
# We don't have gdata-java in Fedora any longer, use commons-codec instead
Patch1:         0002-Replace-bundled-gdata-java-client-classes-with-commo.patch
Patch2:         reader_bom_test_fix.patch

BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

BuildRequires:  maven-local
BuildRequires:  mvn(commons-codec:commons-codec)
BuildRequires:  mvn(commons-io:commons-io)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.commons:commons-lang3)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-source-plugin)
BuildRequires:  mvn(org.apache.velocity:velocity)

%description
SnakeYAML features:
    * a complete YAML 1.1 parser. In particular,
      SnakeYAML can parse all examples from the specification.
    * Unicode support including UTF-8/UTF-16 input/output.
    * high-level API for serializing and deserializing
      native Java objects.
    * support for all types from the YAML types repository.
    * relatively sensible error messages.


%package        javadoc
Summary:        API documentation for %{name}

%description    javadoc
This package contains %{summary}.


%prep
%setup -q -n %{name}-%{name}-%{vertag}
%patch -p2 -P 0
%patch -p2 -P 1
# Remove gdata code which we've replaced
rm -r src/main/java/org/yaml/snakeyaml/external/com
%patch -p2 -P 2


%mvn_file : %{name}

%pom_remove_plugin :formatter-maven-plugin
%pom_remove_plugin :maven-changes-plugin
%pom_remove_plugin :maven-enforcer-plugin
%pom_remove_plugin :maven-license-plugin
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :maven-site-plugin
%pom_remove_plugin :nexus-staging-maven-plugin
%pom_xpath_replace pom:project/pom:properties/pom:maven.compiler.source '<maven.compiler.source>8</maven.compiler.source>'
%pom_xpath_replace pom:project/pom:properties/pom:maven.compiler.target '<maven.compiler.target>8</maven.compiler.target>'
%pom_xpath_replace pom:project/pom:properties/pom:maven.compiler.release '<maven.compiler.release>8</maven.compiler.release>'

# Replacement for bundled gdata-java-client
%pom_add_dep commons-codec:commons-codec

# Unnecessary test-time only dependency
%pom_remove_dep joda-time:joda-time
%pom_remove_dep org.openjdk.jmh:jmh-core
%pom_remove_dep org.openjdk.jmh:jmh-generator-annprocess
rm -rf src/test/java/examples/jodatime
rm -rf src/test/java/org/yaml/snakeyaml/jmh
%pom_remove_dep org.projectlombok:lombok
%pom_remove_dep org.apache.velocity:velocity-engine-core

# fails in rpmbuild only due to different locale
rm src/test/java/org/yaml/snakeyaml/issues/issue67/NonAsciiCharsInClassNameTest.java
# fails after unbundling
rm src/test/java/org/yaml/snakeyaml/issues/issue318/ContextClassLoaderTest.java

# Tests using dependencies we don't have/have removed
rm src/test/java/org/yaml/snakeyaml/emitter/template/VelocityTest.java
rm src/test/java/org/yaml/snakeyaml/issues/issue387/YamlExecuteProcessContextTest.java
rm src/test/java/org/yaml/snakeyaml/env/ApplicationProperties.java
rm src/test/java/org/yaml/snakeyaml/env/EnvLombokTest.java
rm src/test/java/org/yaml/snakeyaml/issues/issue527/Fuzzy47047Test.java
rm src/test/java/org/yaml/snakeyaml/issues/issue530/Fuzzy47039Test.java
rm src/test/java/org/yaml/snakeyaml/issues/issue543/Fuzzer50355Test.java
rm src/test/java/org/yaml/snakeyaml/issues/issue525/FuzzyStackOverflowTest.java
rm src/test/java/org/yaml/snakeyaml/issues/issue529/Fuzzy47028Test.java
rm src/test/java/org/yaml/snakeyaml/issues/issue531/Fuzzy47081Test.java
rm src/test/java/org/yaml/snakeyaml/issues/issue526/Fuzzy47027Test.java

# Problematic test resources for maven-resources-plugin 3.2
#rm src/test/resources/issues/issue99.jpeg
rm src/test/resources/reader/unicode-16be.txt
rm src/test/resources/reader/unicode-16le.txt
rm src/test/resources/pyyaml/spec-05-01-utf16be.data
rm src/test/resources/pyyaml/spec-05-01-utf16le.data
rm src/test/resources/pyyaml/spec-05-02-utf16le.data
rm src/test/resources/pyyaml/odd-utf16.stream-error
rm src/test/resources/pyyaml/invalid-character.loader-error
rm src/test/resources/pyyaml/invalid-character.stream-error
rm src/test/resources/pyyaml/invalid-utf8-byte.loader-error
rm src/test/resources/pyyaml/invalid-utf8-byte.stream-error
rm src/test/resources/pyyaml/empty-document-bug.data
rm src/test/resources/pyyaml/spec-05-02-utf16be.data
rm -rf src/test/resources/fuzzer/
# Test using the jpeg data removed above
#rm src/test/java/org/yaml/snakeyaml/issues/issue99/YamlBase64Test.java

# convert CR+LF to LF
sed -i 's/\r//g' LICENSE.txt


%build
%mvn_build


%install
%mvn_install


%files -f .mfiles
%doc LICENSE.txt

%files javadoc -f .mfiles-javadoc
%doc LICENSE.txt




%changelog
* Sun May 26 2024 daviddavid <daviddavid> 2.2-1.mga10
+ Revision: 2067702
- Update to latest upstream release
- Resolves: CVE-2022-1471
- Rebuilt for java-21-openjdk as system jdk

* Tue Mar 14 2023 daviddavid <daviddavid> 1.32-1.mga9
+ Revision: 1948941
- Update to latest upstream 1.32 release
- Resolves: CVE-2020-13936, CVE-2022-25857, CVE-2022-38749, CVE-2022-3875[0-2], CVE-2022-41854
  (mga#30899)

* Fri Dec 09 2022 daviddavid <daviddavid> 1.27-3.mga9
+ Revision: 1919845
- Fix maven-resources-plugin 3.2 issues. Fixes FTBFS.
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Mon Mar 01 2021 daviddavid <daviddavid> 1.27-1.mga9
+ Revision: 1694832
- Update to version 1.27

* Sat Jan 09 2021 daviddavid <daviddavid> 1.26-3.mga8
+ Revision: 1670091
- rebuild with fixed velocity

* Fri Sep 11 2020 daviddavid <daviddavid> 1.26-2.mga8
+ Revision: 1624418
- Drop unnecessary dep on joda-time
- Rebuilt for JDK-11

* Fri May 01 2020 daviddavid <daviddavid> 1.26-1.mga8
+ Revision: 1577402
- Update to latest upstream 1.26 release
- Resolves: CVE-2017-18640 (mga#26556)

* Sun Feb 16 2020 umeabot <umeabot> 1.25-4.mga8
+ Revision: 1536338
- Mageia 8 Mass Rebuild

* Wed Oct 16 2019 daviddavid <daviddavid> 1.25-3.mga8
+ Revision: 1454067
- Replace base64coder dependency with java.util.Base64 from JDK8

* Tue Oct 15 2019 daviddavid <daviddavid> 1.25-2.mga8
+ Revision: 1453384
- Backport fix for a broken test from upstream

* Tue Oct 15 2019 daviddavid <daviddavid> 1.25-1.mga8
+ Revision: 1453337
- Update to version 1.25

* Thu Aug 01 2019 daviddavid <daviddavid> 1.17-3.mga8
+ Revision: 1426776
- Disable support for spring

* Fri Sep 21 2018 umeabot <umeabot> 1.17-2.mga7
+ Revision: 1291490
- Mageia 7 Mass Rebuild

* Fri Aug 31 2018 daviddavid <daviddavid> 1.17-1.mga7
+ Revision: 1255817
- new version: 1.17 (sync with fc29)
+ neoclust <neoclust>
- Second rebuild of the java stack

* Wed Feb 24 2016 neoclust <neoclust> 1.16-2.mga6
+ Revision: 978185
- First rebuild of the java stack
- sync package snakeyaml with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Mon Dec 29 2014 daviddavid <daviddavid> 1.13-6.mga5
+ Revision: 807117
- Sync with fc21
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Tue Jan 07 2014 dmorgan <dmorgan> 1.13-3.mga4
+ Revision: 565292
- Rebuild against fixed maven-eclipse-plugin

* Tue Oct 22 2013 umeabot <umeabot> 1.13-2.mga4
+ Revision: 541287
- Mageia 4 Mass Rebuild

* Fri Oct 11 2013 dmorgan <dmorgan> 1.13-1.mga4
+ Revision: 495454
- New version

* Fri Sep 27 2013 dmorgan <dmorgan> 1.11-3.mga4
+ Revision: 487886
- Replace bundled base64 implementation
  Explain gdata-java and base64 bundling situation
  Build with xmvn

* Mon Jan 14 2013 umeabot <umeabot> 1.11-2.mga3
+ Revision: 382245
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 03 2012 dmorgan <dmorgan> 1.11-1.mga3
+ Revision: 325867
- New version

* Sat Feb 25 2012 gil <gil> 1.9-1.mga2
+ Revision: 214933
- update to 1.9

* Mon Dec 26 2011 gil <gil> 1.8-1.mga2
+ Revision: 187912
- various build fix

* Wed Jul 20 2011 dmorgan <dmorgan> 1.8-0.mga2
+ Revision: 127299
- Remove wrong spec file
- Revert to our previous spec file
- Add missing file
- Sync with fedora
+ gil <gil>
- imported package snakeyaml


* Mon Jun 13 2011 gil <gil> 1.8-0.%%mkrel
- initial rpm